@@ -366,7 +366,8 @@ void CopyJobPrivate::slotResultStating(KJob *job)
             info.uDest = m_dest;
             // Append filename or dirname to destination URL, if allowed
             if (destinationState == DEST_IS_DIR && !m_asMethod) {
-                info.uDest = addPathToUrl(info.uDest, srcurl.fileName());
+                const QString fileName = srcurl.scheme() == "data" ? "data" : srcurl.fileName(); // #379093
+                info.uDest = addPathToUrl(info.uDest, fileName);
             }
 
             files.append(info);
