@@ -358,6 +358,8 @@ bool KFileItemPrivate::cmp(const KFileItemPrivate &item) const
             && size() == item.size()
             && m_entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME) == item.m_entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME)
             && m_entry.stringValue(KIO::UDSEntry::UDS_ICON_NAME) == item.m_entry.stringValue(KIO::UDSEntry::UDS_ICON_NAME)
+            && m_entry.stringValue(KIO::UDSEntry::UDS_TARGET_URL) == item.m_entry.stringValue(KIO::UDSEntry::UDS_TARGET_URL)
+            && m_entry.stringValue(KIO::UDSEntry::UDS_LOCAL_PATH) == item.m_entry.stringValue(KIO::UDSEntry::UDS_LOCAL_PATH)
            );
 
     // Don't compare the mimetypes here. They might not be known, and we don't want to
@@ -450,7 +452,7 @@ QString KFileItemPrivate::parsePermissions(mode_t perm) const
 ///////
 
 KFileItem::KFileItem()
-    : d(0)
+    : d(nullptr)
 {
 }
 
@@ -1335,7 +1337,7 @@ QDataStream &operator>> (QDataStream &s, KFileItem &a)
     }
 
     if (url.isEmpty()) {
-        a.d = 0;
+        a.d = nullptr;
         return s;
     }
 
@@ -1494,7 +1496,7 @@ KFileItem &KFileItem::operator=(const KFileItem &other)
 
 bool KFileItem::isNull() const
 {
-    return d == 0;
+    return d == nullptr;
 }
 
 KFileItemList::KFileItemList()
