@@ -42,13 +42,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qstandardpaths.h>
 #include <QMessageBox>
 
+#include <QLoggingCategory>
+Q_DECLARE_LOGGING_CATEGORY(KIO_COOKIEJAR)
+
 #include "kcookiejar.h"
 #include "kcookiewin.h"
 #include "kcookieserveradaptor.h"
 
-#define QL1S(x)  QLatin1String(x)
-#define QL1C(x)  QLatin1Char(x)
-
 K_PLUGIN_FACTORY_WITH_JSON(KdedCookieServerFactory,
                            "kcookiejar.json",
                            registerPlugin<KCookieServer>();)
@@ -56,16 +56,16 @@ K_PLUGIN_FACTORY_WITH_JSON(KdedCookieServerFactory,
 static QDir getOrCreateCookieJarDir()
 {
     const QDir dataDir(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation));
-    const QString kcookiejarDirName = dataDir.absoluteFilePath("kcookiejar");
+    const QString kcookiejarDirName = dataDir.absoluteFilePath(QStringLiteral("kcookiejar"));
 
-    if (dataDir.exists("kcookiejar")) {
+    if (dataDir.exists(QStringLiteral("kcookiejar"))) {
         const QFileInfo cookiejarDirInfo(kcookiejarDirName);
 
         if (!cookiejarDirInfo.isDir()) {
             QFile kcookieBogusFile(kcookiejarDirName);
 
             if (!kcookieBogusFile.remove()) {
-                QMessageBox::warning(Q_NULLPTR, i18n("Cannot Save Cookies"), i18n("Could not remove %1, check permissions").arg(cookiejarDirInfo.absoluteFilePath()));
+                QMessageBox::warning(nullptr, i18n("Cannot Save Cookies"), i18n("Could not remove %1, check permissions").arg(cookiejarDirInfo.absoluteFilePath()));
             }
         }
         else {
@@ -73,8 +73,8 @@ static QDir getOrCreateCookieJarDir()
         }
     }
 
-    if (!dataDir.mkdir("kcookiejar")) {
-        QMessageBox::warning(Q_NULLPTR, i18n("Cannot Save Cookies"), i18n("Could not create directory %1").arg(kcookiejarDirName));
+    if (!dataDir.mkpath(QStringLiteral("kcookiejar"))) {
+        QMessageBox::warning(nullptr, i18n("Cannot Save Cookies"), i18n("Could not create directory %1").arg(kcookiejarDirName));
     }
 
     return QDir(kcookiejarDirName);
@@ -115,7 +115,7 @@ KCookieServer::KCookieServer(QObject *parent, const QList<QVariant> &)
     connect(mTimer, SIGNAL(timeout()), SLOT(slotSave()));
     mConfig = new KConfig(QStringLiteral("kcookiejarrc"));
     mCookieJar->loadConfig(mConfig);
-    mFilename = getOrCreateCookieJarDir().absoluteFilePath("cookies");
+    mFilename = getOrCreateCookieJarDir().absoluteFilePath(QStringLiteral("cookies"));
     mCookieJar->loadCookies(mFilename);
     connect(this, SIGNAL(windowUnregistered(qlonglong)),
             this, SLOT(slotDeleteSessionCookies(qlonglong)));
@@ -175,7 +175,7 @@ void KCookieServer::addCookies(const QString &url, const QByteArray &cookieHeade
     if (!mAdvicePending) {
         mAdvicePending = true;
         while (!mPendingCookies->isEmpty()) {
-            checkCookies(0, windowId);
+            checkCookies(nullptr, windowId);
         }
         mAdvicePending = false;
     }
@@ -209,7 +209,8 @@ void KCookieServer::checkCookies(KHttpCookieList *cookieList, qlonglong windowId
         case KCookieReject:
             cookieIterator.remove();
             break;
-        default:
+        case KCookieDunno:
+        case KCookieAsk:
             break;
         }
     }
@@ -233,7 +234,7 @@ void KCookieServer::checkCookies(KHttpCookieList *cookieList, qlonglong windowId
     }
     //qDebug() << shownCookies;
 
-    KCookieWin *kw = new KCookieWin(0L, currentList,
+    KCookieWin *kw = new KCookieWin(nullptr, currentList,
                                     mCookieJar->preferredDefaultPolicy(),
                                     mCookieJar->showCookieDetails());
     if (windowId > 0) {
@@ -275,8 +276,9 @@ void KCookieServer::checkCookies(KHttpCookieList *cookieList, qlonglong windowId
             cookieIterator2.remove();
             break;
 
-        default:
-            qWarning() << "userAdvice not accept or reject, this should never happen!";
+        case KCookieDunno:
+        case KCookieAsk:
+            qCWarning(KIO_COOKIEJAR) << "userAdvice not accept or reject, this should never happen!";
             break;
         }
     }
